@@ -91,7 +91,7 @@ class TorchFitter:
             # Run one train step
             t = time.time()
             summary_loss = self.train_one_epoch(train_loader)
-            history['train'] = summary_loss.avg
+            history['train'] = summary_loss.avg  # training loss
 
             self.log(f'[RESULT]: Train. Epoch: {self.epoch}, summary_loss: {summary_loss.avg:.5f}, '
                      f'time: {(time.time() - t):.5f}')
@@ -100,7 +100,8 @@ class TorchFitter:
             # Run one validation step
             t = time.time()
             summary_loss = self.validation(validation_loader)
-            history['val'] = summary_loss.avg
+            history['val'] = summary_loss.avg  # validation loss
+            history['lr'] = self.optimizer.param_groups[0]['lr']
 
             self.log(f'[RESULT]: Val. Epoch: {self.epoch}, summary_loss: {summary_loss.avg:.5f}, '
                      f'time: {(time.time() - t):.5f}')
